
import pathlib
import setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setuptools.setup(
    name="tinymovr",
    version="0.1.0",
    author="Yannis Chatzikonstantinou",
    author_email="info@tinymovr.com",
    description="Tinymovr Studio",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/yconst/Tinymovr",
    packages=['tinymovr'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        "ipython",
        "python-can",
        "pyserial",
        "docopt"
    ],
    entry_points={
        'can.interface': [
            "arduino_can=tinymovr.bus:ArduinoCAN",
        ],
        "console_scripts": [
            "tinymovr=tinymovr.shell:spawn_shell"
        ],
    }
    
)

